Re: [PATCH v5 0/8] hash.h: support choosing a separate SHA-1 for non-cryptographic uses
- From
Junio C Hamano <gitster@pobox.com>
- Date
- Sep 27, 2024, 00:44 UTC
- Message-ID
- <xmqqy13egc23.fsf@gitster.g>
- In-Reply-To
- <CABPp-BH3y96DjapzLPJ+vCoChQiD_wR9uLc3QPsXqzSUr4AFvQ@mail.gmail.com>
Elijah Newren <newren@gmail.com> writes:
Show 9 quoted lines
> Hi... > >> ... >> - , and generate the resulting "clone" much unsafeer, in only 11.597 seconds >> + , and generate the resulting "clone" much faster, in only 11.597 seconds >> of wall time, 11.37 seconds of user time, and 0.23 seconds of system >> time, for a ~40% speed-up. > > This round looks good to me.
Thanks, both.